@@ -1,11 +1,9 @@
-pub mod init;
-pub mod set_expiration;
-pub mod extend_expiration;
-pub mod invalidate;
 pub mod close;
+pub mod extend_expiration;
+pub mod init;
+pub mod invalidate;
 
-pub use init::*;
-pub use set_expiration::*;
-pub use extend_expiration::*;
-pub use invalidate::*;
 pub use close::*;
+pub use extend_expiration::*;
+pub use init::*;
+pub use invalidate::*;
